package org.xtext.example.mydsl.serializer;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;
import org.xtext.example.mydsl.myDsl.Assign;
import org.xtext.example.mydsl.myDsl.Block;
import org.xtext.example.mydsl.myDsl.Enclosed;
import org.xtext.example.mydsl.myDsl.Equal;
import org.xtext.example.mydsl.myDsl.Factorial;
import org.xtext.example.mydsl.myDsl.For;
import org.xtext.example.mydsl.myDsl.Function;
import org.xtext.example.mydsl.myDsl.Import;
import org.xtext.example.mydsl.myDsl.ImportItem;
import org.xtext.example.mydsl.myDsl.In;
import org.xtext.example.mydsl.myDsl.Literal;
import org.xtext.example.mydsl.myDsl.Local;
import org.xtext.example.mydsl.myDsl.Model;
import org.xtext.example.mydsl.myDsl.MyDslPackage;
import org.xtext.example.mydsl.myDsl.Name;
import org.xtext.example.mydsl.myDsl.Parameter;
import org.xtext.example.mydsl.myDsl.Plus;
import org.xtext.example.mydsl.myDsl.Rule;
import org.xtext.example.mydsl.myDsl.Sequence;
import org.xtext.example.mydsl.services.MyDslGrammarAccess;

@SuppressWarnings("all")
public class MyDslSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private MyDslGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == MyDslPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case MyDslPackage.ASSIGN:
				if(context == grammarAccess.getAssignExprRule() ||
				   context == grammarAccess.getStatementRule()) {
					sequence_AssignExpr(context, (Assign) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.BLOCK:
				if(context == grammarAccess.getBlockRule()) {
					sequence_Block(context, (Block) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.ENCLOSED:
				if(context == grammarAccess.getEnclosedRule() ||
				   context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getPrimaryRule() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0()) {
					sequence_Enclosed(context, (Enclosed) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.EQUAL:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0()) {
					sequence_EqualityExpression(context, (Equal) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.FACTORIAL:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule()) {
					sequence_FactorialExpression(context, (Factorial) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.FOR:
				if(context == grammarAccess.getForRule() ||
				   context == grammarAccess.getStatementRule()) {
					sequence_For(context, (For) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.FUNCTION:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0()) {
					sequence_PrimaryExpression(context, (Function) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.IMPORT:
				if(context == grammarAccess.getImportRule() ||
				   context == grammarAccess.getStatementRule()) {
					sequence_Import(context, (Import) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.IMPORT_ITEM:
				if(context == grammarAccess.getImportItemRule()) {
					sequence_ImportItem(context, (ImportItem) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.IN:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0()) {
					sequence_EqualityExpression(context, (In) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.LITERAL:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getLiteralRule() ||
				   context == grammarAccess.getPrimaryRule() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0()) {
					sequence_Literal(context, (Literal) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.LOCAL:
				if(context == grammarAccess.getDeclarationRule() ||
				   context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getPrimaryRule() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0() ||
				   context == grammarAccess.getVarRule()) {
					sequence_Var(context, (Local) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.MODEL:
				if(context == grammarAccess.getModelRule()) {
					sequence_Model(context, (Model) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.NAME:
				if(context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getNameRule() ||
				   context == grammarAccess.getPrimaryRule() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0()) {
					sequence_Name(context, (Name) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.PARAMETER:
				if(context == grammarAccess.getDeclarationRule() ||
				   context == grammarAccess.getParameterRule()) {
					sequence_Parameter(context, (Parameter) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.PLUS:
				if(context == grammarAccess.getExpressionRule()) {
					sequence_Expression(context, (Plus) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.RULE:
				if(context == grammarAccess.getDeclarationRule() ||
				   context == grammarAccess.getEqualityExpressionRule() ||
				   context == grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0() ||
				   context == grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0() ||
				   context == grammarAccess.getExpressionRule() ||
				   context == grammarAccess.getExpressionAccess().getPlusLeftAction_1_0() ||
				   context == grammarAccess.getFactorialExpressionRule() ||
				   context == grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0() ||
				   context == grammarAccess.getPrimaryRule() ||
				   context == grammarAccess.getPrimaryExpressionRule() ||
				   context == grammarAccess.getPrimaryExpressionAccess().getFunctionScopeAction_1_0() ||
				   context == grammarAccess.getRuleRule()) {
					sequence_Rule(context, (Rule) semanticObject); 
					return; 
				}
				else break;
			case MyDslPackage.SEQUENCE:
				if(context == grammarAccess.getAssignExprRule() ||
				   context == grammarAccess.getAssignExprAccess().getAssignLeftAction_1_0() ||
				   context == grammarAccess.getSequenceRule() ||
				   context == grammarAccess.getStatementRule()) {
					sequence_Sequence(context, (Sequence) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     (left=AssignExpr_Assign_1_0 right=Sequence)
	 */
	protected void sequence_AssignExpr(EObject context, Assign semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.ASSIGN__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.ASSIGN__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.ASSIGN__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.ASSIGN__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getAssignExprAccess().getAssignLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getAssignExprAccess().getRightSequenceParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (statemets+=Statement statemets+=Statement*)
	 */
	protected void sequence_Block(EObject context, Block semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (args=Sequence?)
	 */
	protected void sequence_Enclosed(EObject context, Enclosed semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (left=EqualityExpression_Equal_1_0_1_0 right=FactorialExpression)
	 */
	protected void sequence_EqualityExpression(EObject context, Equal semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.EQUAL__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.EQUAL__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.EQUAL__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.EQUAL__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getEqualityExpressionAccess().getEqualLeftAction_1_0_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getEqualityExpressionAccess().getRightFactorialExpressionParserRuleCall_1_1_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (left=EqualityExpression_In_1_0_0_0 right=FactorialExpression)
	 */
	protected void sequence_EqualityExpression(EObject context, In semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.IN__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.IN__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.IN__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.IN__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getEqualityExpressionAccess().getInLeftAction_1_0_0_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getEqualityExpressionAccess().getRightFactorialExpressionParserRuleCall_1_1_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (left=Expression_Plus_1_0 right=EqualityExpression)
	 */
	protected void sequence_Expression(EObject context, Plus semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.PLUS__LEFT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.PLUS__LEFT));
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.PLUS__RIGHT) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.PLUS__RIGHT));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getExpressionAccess().getPlusLeftAction_1_0(), semanticObject.getLeft());
		feeder.accept(grammarAccess.getExpressionAccess().getRightEqualityExpressionParserRuleCall_1_2_0(), semanticObject.getRight());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     expression=FactorialExpression_Factorial_1_0
	 */
	protected void sequence_FactorialExpression(EObject context, Factorial semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.FACTORIAL__EXPRESSION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.FACTORIAL__EXPRESSION));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getFactorialExpressionAccess().getFactorialExpressionAction_1_0(), semanticObject.getExpression());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (name=Name inExpr=Sequence body=Block?)
	 */
	protected void sequence_For(EObject context, For semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=[Declaration|ID] value=Expression?)
	 */
	protected void sequence_ImportItem(EObject context, ImportItem semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (imports+=ImportItem imports+=ImportItem* block=Block?)
	 */
	protected void sequence_Import(EObject context, Import semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     {Literal}
	 */
	protected void sequence_Literal(EObject context, Literal semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     statemets+=Statement*
	 */
	protected void sequence_Model(EObject context, Model semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     name=[Declaration|ID]
	 */
	protected void sequence_Name(EObject context, Name semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, MyDslPackage.Literals.NAME__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, MyDslPackage.Literals.NAME__NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getNameAccess().getNameDeclarationIDTerminalRuleCall_0_1(), semanticObject.getName());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID value=Expression?)
	 */
	protected void sequence_Parameter(EObject context, Parameter semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     ((scope=PrimaryExpression_Function_1_0 args=Sequence?) | scope=PrimaryExpression_Function_1_0)
	 */
	protected void sequence_PrimaryExpression(EObject context, Function semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     ((((parameters+=Parameter parameters+=Parameter*)? name=ID?) | parameters+=Parameter) body=EqualityExpression)
	 */
	protected void sequence_Rule(EObject context, Rule semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (expressions+=Expression expressions+=Expression*)
	 */
	protected void sequence_Sequence(EObject context, Sequence semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID value=Expression?)
	 */
	protected void sequence_Var(EObject context, Local semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
}
